@@ -99,19 +99,19 @@
     <name>ScoresDialog</name>
     <message>
         <source>High Scores</source>
-        <translation type="unfinished"></translation>
+        <translation>Найкращі результати</translation>
     </message>
     <message>
         <source>Rank</source>
-        <translation type="unfinished"></translation>
+        <translation>Ранг</translation>
     </message>
     <message>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Ім&apos;я</translation>
     </message>
     <message>
         <source>Score</source>
-        <translation>Бали</translation>
+        <translation>Очки</translation>
     </message>
     <message>
         <source>Time</source>
@@ -127,23 +127,23 @@
     </message>
     <message>
         <source>#%1</source>
-        <translation type="unfinished"></translation>
+        <translation>#%1</translation>
     </message>
     <message>
         <source>Congratulations!</source>
-        <translation type="unfinished"></translation>
+        <translation>Вітаємо!</translation>
     </message>
     <message>
         <source>You beat your top score!</source>
-        <translation type="unfinished"></translation>
+        <translation>Ви покращили свій найкращий результат!</translation>
     </message>
     <message>
         <source>Well done!</source>
-        <translation type="unfinished"></translation>
+        <translation>Чудово!</translation>
     </message>
     <message>
         <source>You have a new high score!</source>
-        <translation type="unfinished"></translation>
+        <translation>У вас новий найкращий результат!</translation>
     </message>
 </context>
 <context>
@@ -231,11 +231,11 @@
     </message>
     <message>
         <source>High &amp;Scores</source>
-        <translation type="unfinished"></translation>
+        <translation>Найкращі &amp;результати</translation>
     </message>
     <message>
         <source>Ctrl+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+H</translation>
     </message>
     <message>
         <source>&amp;Quit</source>
@@ -247,7 +247,7 @@
     </message>
     <message>
         <source>&amp;Dark Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Темний режим</translation>
     </message>
     <message>
         <source>Application &amp;Language...</source>
